summaryrefslogtreecommitdiff
path: root/ace/Event_Handler.h
diff options
context:
space:
mode:
authorbala <balanatarajan@users.noreply.github.com>2002-06-19 19:14:56 +0000
committerbala <balanatarajan@users.noreply.github.com>2002-06-19 19:14:56 +0000
commite3f3424d8906509541f106c3d912b9949bbbf7f2 (patch)
tree6f5cf873db35fda52acd852127ddb2d555507765 /ace/Event_Handler.h
parentd4d4b3b96a630da6cb94e98dcc3cbd11d6fbd633 (diff)
downloadATCD-e3f3424d8906509541f106c3d912b9949bbbf7f2.tar.gz
ChangeLogTag:Wed Jun 19 14:25:52 2002 Balachandran Natarajan <bala@cs.wustl.edu>
Diffstat (limited to 'ace/Event_Handler.h')
-rw-r--r--ace/Event_Handler.h21
1 files changed, 15 insertions, 6 deletions
diff --git a/ace/Event_Handler.h b/ace/Event_Handler.h
index 87cf8aa37c7..80bcfe69bda 100644
--- a/ace/Event_Handler.h
+++ b/ace/Event_Handler.h
@@ -130,12 +130,21 @@ public:
/// when a Win32 object becomes signaled).
virtual int handle_signal (int signum, siginfo_t * = 0, ucontext_t * = 0);
- /// Called to figure out whether the handler needs to resumed by the
- /// reactor or the application can take care of it. The default
- /// value of 0 would be returned which would allow the reactor to
- /// take care of resumption of the handler. The application can
- /// return a value more than zero and decide to resume the handler
- /// themseleves.
+ enum
+ {
+ ACE_REACTOR_RESUMES_HANDLER = 0,
+ ACE_APPLICATION_RESUMES_HANDLER
+ };
+ /* Called to figure out whether the handler needs to resumed by the
+ * reactor or the application can take care of it. The default
+ * value of 0 would be returned which would allow the reactor to
+ * take care of resumption of the handler. The application can
+ * return a value more than zero and decide to resume the handler
+ * themseleves.
+ */
+ // @@ NOTE: This method is only useful for the ACE_TP_Reactor. Sad
+ // that we have to have this method in a class that is supposed to
+ // be used across different componets in ACE.
virtual int resume_handler (void);
virtual int handle_qos (ACE_HANDLE = ACE_INVALID_HANDLE);